@@ -18,7 +18,7 @@ sub register {
 
     # Default plugins
     $app->plugin('charset' => {charset => 'utf-8'});
-    $app->plugin('PODRenderer');
+    $app->plugin('PODRenderer', {no_perldoc => 1});
     $app->plugin('TagHelpers');
     $app->plugin(
         validator => {
@@ -157,7 +157,7 @@ sub _default {
             archive => '/articles.html'
         ],
         footer =>
-          'Powered by <a href="http://getbootylicious.org">Bootylicious</a>',
+          'Powered by <a href="https://github.com/vti/bootylicious">Bootylicious</a>',
         theme => '',
 
         comments_enabled => 1,
